.. highlight:: shell

===========
Instalación
===========


Versión estable
---------------

Para instalar pyrobo, ejecute el siguiente comando en una terminal:

.. code-block:: console

    $ pip install pyrobo

Esta es la forma recomendada de instalar pyrobo, ya que siempre instala la
versión estable más reciente.

Si no tiene `pip`_ instalado, esta `guía de instalación de Python`_ puede
guiarte en el proceso.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


Desde código fuente
-------------------

El código fuente para pyrobo se pueden descargar del `repo de Github`_.

Puede clonar el repositorio público:

.. code-block:: console

    $ git clone git://github.com/nicoguaro/pyrobo

O descargar el archivo `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/nicoguaro/pyrobo/tarball/master

Una vez tenga una copia de los archivos fuente, puede instalar con:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/nicoguaro/pyrobo
.. _tarball: https://github.com/nicoguaro/pyrobo/tarball/master
